@@ -142,10 +142,15 @@ IPA_PeaklistAnnotation <- function(PARAM) {
               ## To back calculate the RT ##
               uncorrected_RTi <- matrix(loadRdata(paste0(input_path_peaklist, "/", file_names_peaklist[i]))[, 3], ncol = 1)
               corrected_RTi <- corrected_RT_peaklists[[i]]
-              idf <- data.frame(uncoRT = uncorrected_RTi, coRT = corrected_RTi)
-              rtmodel <- lm(coRT ~ poly(uncoRT, 3), idf)
-              new.df <- data.frame(uncoRT = undeteced_RT) # predict uncorrected RTs
-              RT_uncorrected_undeteced <- matrix(predict(rtmodel, new.df), ncol = 1)
+              ##
+              if (!is.na(corrected_RTi[1])) {
+                idf <- data.frame(uncoRT = uncorrected_RTi, coRT = corrected_RTi)
+                rtmodel <- lm(coRT ~ poly(uncoRT, 3), idf)
+                new.df <- data.frame(uncoRT = undeteced_RT) # predict uncorrected RTs
+                RT_uncorrected_undeteced <- matrix(predict(rtmodel, new.df), ncol = 1)
+              } else {
+                RT_uncorrected_undeteced <- matrix(undeteced_RT, ncol = 1)
+              }
             } else {
               RT_uncorrected_undeteced <- matrix(undeteced_RT, ncol = 1)
             }
@@ -244,10 +249,15 @@ IPA_PeaklistAnnotation <- function(PARAM) {
               ## To back calculate the RT ##
               uncorrected_RTi <- matrix(loadRdata(paste0(input_path_peaklist, "/", file_names_peaklist[i]))[, 3], ncol = 1)
               corrected_RTi <- corrected_RT_peaklists[[i]]
-              idf <- data.frame(uncoRT = uncorrected_RTi, coRT = corrected_RTi)
-              rtmodel <- lm(coRT ~ poly(uncoRT, 3), idf)
-              new.df <- data.frame(uncoRT = undeteced_RT) # predict uncorrected RTs
-              RT_uncorrected_undeteced <- matrix(predict(rtmodel, new.df), ncol = 1)
+              ##
+              if (!is.na(corrected_RTi[1])) {
+                idf <- data.frame(uncoRT = uncorrected_RTi, coRT = corrected_RTi)
+                rtmodel <- lm(coRT ~ poly(uncoRT, 3), idf)
+                new.df <- data.frame(uncoRT = undeteced_RT) # predict uncorrected RTs
+                RT_uncorrected_undeteced <- matrix(predict(rtmodel, new.df), ncol = 1)
+              } else {
+                RT_uncorrected_undeteced <- matrix(undeteced_RT, ncol = 1)
+              }
             } else {
               RT_uncorrected_undeteced <- matrix(undeteced_RT, ncol = 1)
             }
